/////////////////////////////////////////////////////////////////////////
//
// RooFit tutorial macro #14
// 
// Reading and using a workspace
//
// --> The input file for this macro is generated by rf13_wspaceread.C
// 
//
/////////////////////////////////////////////////////////////////////////

#ifndef __CINT__
#include "RooGlobalFunc.h"
#endif
#include "RooRealVar.h"
#include "RooDataSet.h"
#include "RooGaussian.h"
#include "RooChebychev.h"
#include "RooAddPdf.h"
#include "RooWorkspace.h"
#include "RooPlot.h"
#include "TCanvas.h"
#include "TFile.h"
#include "TH1.h"
using namespace RooFit ;


void rf14_wspaceread()
{
  // Open input file with workspace (generated by rf14_wspacewrite)
  TFile *f = new TFile("rf13_workspace.root") ;

  // Retrieve workspace from file
  RooWorkspace* w = (RooWorkspace*) f->Get("w") ;

  // Retrieve x,model and data from workspace
  RooRealVar* x = w->var("x") ;
  RooAbsPdf* model = w->pdf("model") ;
  RooAbsData* data = w->data("modelData") ;

  // --- Code below identical to rf02_composite

  // Fit model to data (skip MINOS)
  model->fitTo(*data, Minos(kFALSE)) ;
  
  // Plot data and PDF overlaid
  RooPlot* xframe = x->frame() ;
  data->plotOn(xframe) ;
  model->plotOn(xframe) ;

  // Overlay the background component of model with a dashed line
  model->plotOn(xframe,Components("bkg"),LineStyle(kDashed)) ;

  // Overlay the background+sig2 components of model with a dotted line
  model->plotOn(xframe,Components("bkg,sig2"),LineStyle(kDotted)) ;

  // Draw the frame on the canvas
  new TCanvas("rf14_wspaceread","rf14_wspaceread",600,600) ;
  xframe->Draw() ;

  // Print structure of composite p.d.f.
  model->Print("t") ;


}
